@@ -1,7 +1,7 @@
 package Pod::Elemental::Element::Pod5::Command;
-our $VERSION = '0.093280';
-
-
+BEGIN {
+  $Pod::Elemental::Element::Pod5::Command::VERSION = '0.102360';
+}
 use Moose;
 # ABSTRACT: a Pod5 =command element
 
@@ -9,6 +9,12 @@ extends 'Pod::Elemental::Element::Generic::Command';
 with    'Pod::Elemental::Autoblank';
 with    'Pod::Elemental::Autochomp';
 
+use Pod::Elemental::Types qw(ChompedString);
+has '+content' => (
+  coerce => 1,
+  isa    => ChompedString,
+);
+
 
 use namespace::autoclean;
 
@@ -23,7 +29,7 @@ Pod::Elemental::Element::Pod5::Command - a Pod5 =command element
 
 =head1 VERSION
 
-version 0.093280
+version 0.102360
 
 =head1 OVERVIEW
 
@@ -34,11 +40,11 @@ paragraphs in a Pod5 document.
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo SIGNES.
+This software is copyright (c) 2010 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
