@@ -1,13 +1,18 @@
 package Pod::Elemental::Element::Pod5::Verbatim;
-our $VERSION = '0.093280';
-
-
+BEGIN {
+  $Pod::Elemental::Element::Pod5::Verbatim::VERSION = '0.102360';
+}
 use Moose;
 extends 'Pod::Elemental::Element::Generic::Text';
 with    'Pod::Elemental::Autoblank';
 with    'Pod::Elemental::Autochomp';
 # ABSTRACT: a Pod verbatim paragraph
 
+# BEGIN Autochomp Replacement
+use Pod::Elemental::Types qw(ChompedString);
+has '+content' => (coerce => 1, isa => ChompedString);
+# END   Autochomp Replacement
+
 
 use namespace::autoclean;
 
@@ -22,7 +27,7 @@ Pod::Elemental::Element::Pod5::Verbatim - a Pod verbatim paragraph
 
 =head1 VERSION
 
-version 0.093280
+version 0.102360
 
 =head1 OVERVIEW
 
@@ -37,11 +42,11 @@ following paragraph is a verbatim paragraph:
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Ricardo SIGNES.
+This software is copyright (c) 2010 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
